@@ -1,19 +1,17 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import logging
 
@@ -56,21 +54,21 @@ SANDBOXES_SCHEMA = {
 }
 
 
-async def summary(client: Client) -> dict:
+def summary(client: Client) -> dict:
     """
     GET Duniter node version and infos
 
     :param client: Client to connect to the api
     :return:
     """
-    return await client.get(MODULE + "/summary", schema=SUMMARY_SCHEMA)
+    return client.get(f"{MODULE}/summary", schema=SUMMARY_SCHEMA)
 
 
-async def sandboxes(client: Client) -> dict:
+def sandboxes(client: Client) -> dict:
     """
     GET Duniter node version and infos
 
     :param client: Client to connect to the api
     :return:
     """
-    return await client.get(MODULE + "/sandboxes", schema=SANDBOXES_SCHEMA)
+    return client.get(f"{MODULE}/sandboxes", schema=SANDBOXES_SCHEMA)
