@@ -1,25 +1,22 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import logging
+from http.client import HTTPResponse
 
-from aiohttp import ClientResponse
-
-from duniterpy.api.client import Client, RESPONSE_AIOHTTP
+from duniterpy.api.client import RESPONSE_HTTP, Client
 
 logger = logging.getLogger("duniter/tx")
 
@@ -125,7 +122,7 @@ SOURCES_SCHEMA = {
 }
 
 
-async def history(client: Client, pubkey: str) -> dict:
+def history(client: Client, pubkey: str) -> dict:
     """
     Get transactions history of public key
 
@@ -133,10 +130,10 @@ async def history(client: Client, pubkey: str) -> dict:
     :param pubkey: Public key
     :return:
     """
-    return await client.get(MODULE + "/history/%s" % pubkey, schema=HISTORY_SCHEMA)
+    return client.get(f"{MODULE}/history/{pubkey}", schema=HISTORY_SCHEMA)
 
 
-async def process(client: Client, transaction_signed_raw: str) -> ClientResponse:
+def process(client: Client, transaction_signed_raw: str) -> HTTPResponse:
     """
     POST a transaction raw document
 
@@ -144,14 +141,14 @@ async def process(client: Client, transaction_signed_raw: str) -> ClientResponse
     :param transaction_signed_raw: Transaction signed raw document
     :return:
     """
-    return await client.post(
-        MODULE + "/process",
+    return client.post(
+        f"{MODULE}/process",
         {"transaction": transaction_signed_raw},
-        rtype=RESPONSE_AIOHTTP,
+        rtype=RESPONSE_HTTP,
     )
 
 
-async def sources(client: Client, pubkey: str) -> dict:
+def sources(client: Client, pubkey: str) -> dict:
     """
     GET transaction sources
 
@@ -159,10 +156,10 @@ async def sources(client: Client, pubkey: str) -> dict:
     :param pubkey: Public key
     :return:
     """
-    return await client.get(MODULE + "/sources/%s" % pubkey, schema=SOURCES_SCHEMA)
+    return client.get(f"{MODULE}/sources/{pubkey}", schema=SOURCES_SCHEMA)
 
 
-async def pending(client: Client, pubkey: str) -> dict:
+def pending(client: Client, pubkey: str) -> dict:
     """
     GET pending transaction history for the given pubkey
 
@@ -170,12 +167,10 @@ async def pending(client: Client, pubkey: str) -> dict:
     :param pubkey: Public key
     :return:
     """
-    return await client.get(
-        MODULE + "/history/%s/pending" % pubkey, schema=HISTORY_SCHEMA
-    )
+    return client.get(f"{MODULE}/history/{pubkey}/pending", schema=HISTORY_SCHEMA)
 
 
-async def blocks(client: Client, pubkey: str, start: int, end: int) -> dict:
+def blocks(client: Client, pubkey: str, start: int, end: int) -> dict:
     """
     GET public key transactions history between start and end block number
 
@@ -185,13 +180,13 @@ async def blocks(client: Client, pubkey: str, start: int, end: int) -> dict:
     :param end: End to block number
     :return:
     """
-    return await client.get(
-        MODULE + "/history/%s/blocks/%s/%s" % (pubkey, start, end),
+    return client.get(
+        f"{MODULE}/history/{pubkey}/blocks/{start}/{end}",
         schema=HISTORY_SCHEMA,
     )
 
 
-async def times(client: Client, pubkey: str, start: int, end: int) -> dict:
+def times(client: Client, pubkey: str, start: int, end: int) -> dict:
     """
     GET public key transactions history between start and end timestamp
 
@@ -201,6 +196,6 @@ async def times(client: Client, pubkey: str, start: int, end: int) -> dict:
     :param end: End to timestamp
     :return:
     """
-    return await client.get(
-        MODULE + "/history/%s/times/%s/%s" % (pubkey, start, end), schema=HISTORY_SCHEMA
+    return client.get(
+        f"{MODULE}/history/{pubkey}/times/{start}/{end}", schema=HISTORY_SCHEMA
     )
