@@ -1,25 +1,22 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import logging
+from http.client import HTTPResponse
 
-from aiohttp import ClientResponse
-
-from duniterpy.api.client import Client, RESPONSE_AIOHTTP
+from duniterpy.api.client import RESPONSE_HTTP, Client
 
 logger = logging.getLogger("duniter/wot")
 
@@ -230,7 +227,7 @@ IDENTITY_OF_SCHEMA = {
 }
 
 
-async def add(client: Client, identity_signed_raw: str) -> ClientResponse:
+def add(client: Client, identity_signed_raw: str) -> HTTPResponse:
     """
     POST identity raw document
 
@@ -238,12 +235,12 @@ async def add(client: Client, identity_signed_raw: str) -> ClientResponse:
     :param identity_signed_raw: Identity raw document
     :return:
     """
-    return await client.post(
-        MODULE + "/add", {"identity": identity_signed_raw}, rtype=RESPONSE_AIOHTTP
+    return client.post(
+        f"{MODULE}/add", {"identity": identity_signed_raw}, rtype=RESPONSE_HTTP
     )
 
 
-async def certify(client: Client, certification_signed_raw: str) -> ClientResponse:
+def certify(client: Client, certification_signed_raw: str) -> HTTPResponse:
     """
     POST certification raw document
 
@@ -251,12 +248,12 @@ async def certify(client: Client, certification_signed_raw: str) -> ClientRespon
     :param certification_signed_raw: Certification raw document
     :return:
     """
-    return await client.post(
-        MODULE + "/certify", {"cert": certification_signed_raw}, rtype=RESPONSE_AIOHTTP
+    return client.post(
+        f"{MODULE}/certify", {"cert": certification_signed_raw}, rtype=RESPONSE_HTTP
     )
 
 
-async def revoke(client: Client, revocation_signed_raw: str) -> ClientResponse:
+def revoke(client: Client, revocation_signed_raw: str) -> HTTPResponse:
     """
     POST revocation document
 
@@ -264,14 +261,14 @@ async def revoke(client: Client, revocation_signed_raw: str) -> ClientResponse:
     :param revocation_signed_raw: Certification raw document
     :return:
     """
-    return await client.post(
-        MODULE + "/revoke",
+    return client.post(
+        f"{MODULE}/revoke",
         {"revocation": revocation_signed_raw},
-        rtype=RESPONSE_AIOHTTP,
+        rtype=RESPONSE_HTTP,
     )
 
 
-async def lookup(client: Client, search: str) -> dict:
+def lookup(client: Client, search: str) -> dict:
     """
     GET UID/Public key data
 
@@ -279,10 +276,10 @@ async def lookup(client: Client, search: str) -> dict:
     :param search: UID or public key
     :return:
     """
-    return await client.get(MODULE + "/lookup/%s" % search, schema=LOOKUP_SCHEMA)
+    return client.get(f"{MODULE}/lookup/{search}", schema=LOOKUP_SCHEMA)
 
 
-async def certifiers_of(client: Client, search: str) -> dict:
+def certifiers_of(client: Client, search: str) -> dict:
     """
     GET UID/Public key certifiers
 
@@ -290,12 +287,10 @@ async def certifiers_of(client: Client, search: str) -> dict:
     :param search: UID or public key
     :return:
     """
-    return await client.get(
-        MODULE + "/certifiers-of/%s" % search, schema=CERTIFICATIONS_SCHEMA
-    )
+    return client.get(f"{MODULE}/certifiers-of/{search}", schema=CERTIFICATIONS_SCHEMA)
 
 
-async def certified_by(client: Client, search: str) -> dict:
+def certified_by(client: Client, search: str) -> dict:
     """
     GET identities certified by UID/Public key
 
@@ -303,22 +298,20 @@ async def certified_by(client: Client, search: str) -> dict:
     :param search: UID or public key
     :return:
     """
-    return await client.get(
-        MODULE + "/certified-by/%s" % search, schema=CERTIFICATIONS_SCHEMA
-    )
+    return client.get(f"{MODULE}/certified-by/{search}", schema=CERTIFICATIONS_SCHEMA)
 
 
-async def members(client: Client) -> dict:
+def members(client: Client) -> dict:
     """
     GET list of all current members of the Web of Trust
 
     :param client: Client to connect to the api
     :return:
     """
-    return await client.get(MODULE + "/members", schema=MEMBERS_SCHEMA)
+    return client.get(f"{MODULE}/members", schema=MEMBERS_SCHEMA)
 
 
-async def requirements(client: Client, search: str) -> dict:
+def requirements(client: Client, search: str) -> dict:
     """
     GET list of requirements for a given UID/Public key
 
@@ -326,12 +319,10 @@ async def requirements(client: Client, search: str) -> dict:
     :param search: UID or public key
     :return:
     """
-    return await client.get(
-        MODULE + "/requirements/%s" % search, schema=REQUIREMENTS_SCHEMA
-    )
+    return client.get(f"{MODULE}/requirements/{search}", schema=REQUIREMENTS_SCHEMA)
 
 
-async def requirements_of_pending(client: Client, minsig: int) -> dict:
+def requirements_of_pending(client: Client, minsig: int) -> dict:
     """
     GET list of requirements of all pending identities with a minimum of minsig certifications
 
@@ -339,12 +330,12 @@ async def requirements_of_pending(client: Client, minsig: int) -> dict:
     :param minsig: Minimum number of certifications
     :return:
     """
-    return await client.get(
-        MODULE + "/requirements-of-pending/%d" % minsig, schema=REQUIREMENTS_SCHEMA
+    return client.get(
+        f"{MODULE}/requirements-of-pending/{minsig}", schema=REQUIREMENTS_SCHEMA
     )
 
 
-async def identity_of(client: Client, search: str) -> dict:
+def identity_of(client: Client, search: str) -> dict:
     """
     GET Identity data written in the blockchain
 
@@ -352,6 +343,4 @@ async def identity_of(client: Client, search: str) -> dict:
     :param search: UID or public key
     :return:
     """
-    return await client.get(
-        MODULE + "/identity-of/%s" % search, schema=IDENTITY_OF_SCHEMA
-    )
+    return client.get(f"{MODULE}/identity-of/{search}", schema=IDENTITY_OF_SCHEMA)
