@@ -1,31 +1,34 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import re
-from typing import TypeVar, List, Type
+from typing import List, Type, TypeVar
 
-from duniterpy.api.endpoint import endpoint, Endpoint
-from .document import Document, MalformedDocumentError
-from .block_uid import BlockUID
-from ..constants import BLOCK_HASH_REGEX, PUBKEY_REGEX
+from duniterpy.api.endpoint import Endpoint, endpoint
+
+from ..constants import BLOCK_HASH_REGEX, G1_CURRENCY_CODENAME, PUBKEY_REGEX
 
 # required to type hint cls in classmethod
+from ..key import SigningKey
+from .block_id import BlockID
+from .document import Document, MalformedDocumentError
+
 PeerType = TypeVar("PeerType", bound="Peer")
 
+VERSION = 10
+
 
 class Peer(Document):
     """
@@ -45,12 +48,8 @@ class Peer(Document):
     """
 
     re_type = re.compile("Type: (Peer)")
-    re_pubkey = re.compile(
-        "PublicKey: ({pubkey_regex})\n".format(pubkey_regex=PUBKEY_REGEX)
-    )
-    re_block = re.compile(
-        "Block: ([0-9]+-{block_hash_regex})\n".format(block_hash_regex=BLOCK_HASH_REGEX)
-    )
+    re_pubkey = re.compile(f"PublicKey: ({PUBKEY_REGEX})\n")
+    re_block = re.compile(f"Block: ([0-9]+-{BLOCK_HASH_REGEX})\n")
     re_endpoints = re.compile("(Endpoints:)\n")
 
     fields_parsers = {
@@ -65,28 +64,31 @@ class Peer(Document):
 
     def __init__(
         self,
-        version: int,
-        currency: str,
         pubkey: str,
-        block_uid: BlockUID,
+        block_id: BlockID,
         endpoints: List[Endpoint],
-        signature: str,
+        signing_key: SigningKey = None,
+        version: int = VERSION,
+        currency: str = G1_CURRENCY_CODENAME,
     ) -> None:
         """
         Init Peer instance
 
-        :param version: Version of the document
-        :param currency: Name of the currency
         :param pubkey: Public key of the issuer
-        :param block_uid: BlockUID instance timestamp
+        :param block_id: BlockID instance
         :param endpoints: List of endpoints string
-        :param signature: Signature of the document
+        :param signing_key: SigningKey instance to sign the document (default=None)
+        :param version: Document version (default=peer.VERSION)
+        :param currency: Currency codename (default=constants.CURRENCY_CODENAME_G1)
         """
-        super().__init__(version, currency, [signature])
+        super().__init__(version, currency)
 
         self.pubkey = pubkey
-        self.blockUID = block_uid
-        self.endpoints = endpoints
+        self.block_id = block_id
+        self.endpoints: List[Endpoint] = endpoints
+
+        if signing_key is not None:
+            self.sign(signing_key)
 
     @classmethod
     def from_signed_raw(cls: Type[PeerType], raw: str) -> PeerType:
@@ -111,7 +113,7 @@ class Peer(Document):
         pubkey = Peer.parse_field("Pubkey", lines[n])
         n += 1
 
-        block_uid = BlockUID.from_str(Peer.parse_field("Block", lines[n]))
+        block_id = BlockID.from_str(Peer.parse_field("Block", lines[n]))
         n += 1
 
         Peer.parse_field("Endpoints", lines[n])
@@ -127,7 +129,11 @@ class Peer(Document):
             raise MalformedDocumentError("Peer")
         signature = data.group(1)
 
-        return cls(version, currency, pubkey, block_uid, endpoints, signature)
+        peer = cls(pubkey, block_id, endpoints, version=version, currency=currency)
+
+        # return peer with signature
+        peer.signature = signature
+        return peer
 
     def raw(self) -> str:
         """
@@ -135,18 +141,15 @@ class Peer(Document):
 
         :return:
         """
-        doc = """Version: {0}
-Type: Peer
-Currency: {1}
-PublicKey: {2}
-Block: {3}
-Endpoints:
-""".format(
-            self.version, self.currency, self.pubkey, self.blockUID
-        )
+        doc = f"Version: {self.version}\n\
+Type: Peer\n\
+Currency: {self.currency}\n\
+PublicKey: {self.pubkey}\n\
+Block: {self.block_id}\n\
+Endpoints:\n"
 
         for _endpoint in self.endpoints:
-            doc += "{0}\n".format(_endpoint.inline())
+            doc += f"{_endpoint.inline()}\n"
 
         return doc
 
@@ -156,7 +159,7 @@ Endpoints:
         version = data["version"]
         currency = data["currency"]
         pubkey = data["pubkey"]
-        block_uid = BlockUID.from_str(data["block"])
+        block_id = BlockID.from_str(data["block"])
 
         endpoints = []
         for _endpoint in data["endpoints"]:
@@ -164,4 +167,8 @@ Endpoints:
 
         signature = str(Peer.re_signature.match(data["signature"]))
 
-        return cls(version, currency, pubkey, block_uid, endpoints, signature)
+        peer = cls(pubkey, block_id, endpoints, version=version, currency=currency)
+
+        # return peer with signature
+        peer.signature = signature
+        return peer
