@@ -1,35 +1,40 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import base64
+import logging
 import re
-from typing import TypeVar, List, Any, Type, Optional, Dict, Union, Tuple
+from typing import Any, Dict, List, Optional, Tuple, Type, TypeVar, Union
 
 import pypeg2
 
 from duniterpy.grammars.output import Condition
-from .block_uid import BlockUID
-from .document import Document, MalformedDocumentError
+
 from ..constants import (
+    BLOCK_ID_REGEX,
+    BLOCK_NUMBER_REGEX,
+    G1_CURRENCY_CODENAME,
     PUBKEY_REGEX,
     TRANSACTION_HASH_REGEX,
-    BLOCK_ID_REGEX,
-    BLOCK_UID_REGEX,
 )
 from ..grammars import output
+from ..key import SigningKey, VerifyingKey
+from .block_id import BlockID
+from .document import Document, MalformedDocumentError
+
+VERSION = 10
 
 
 def reduce_base(amount: int, base: int) -> Tuple[int, int]:
@@ -73,12 +78,8 @@ class InputSource:
     """
 
     re_inline = re.compile(
-        "([0-9]+):([0-9]):(?:(?:(D):({pubkey_regex}):({block_id_regex}))|(?:(T):({transaction_hash_regex}):\
-([0-9]+)))".format(
-            pubkey_regex=PUBKEY_REGEX,
-            block_id_regex=BLOCK_ID_REGEX,
-            transaction_hash_regex=TRANSACTION_HASH_REGEX,
-        )
+        f"([0-9]+):([0-9]):(?:(?:(D):({PUBKEY_REGEX}):({BLOCK_NUMBER_REGEX}))|\
+(?:(T):({TRANSACTION_HASH_REGEX}):([0-9]+)))"
     )
 
     def __init__(
@@ -148,9 +149,7 @@ class InputSource:
 
         :return:
         """
-        return "{0}:{1}:{2}:{3}:{4}".format(
-            self.amount, self.base, self.source, self.origin_id, self.index
-        )
+        return f"{self.amount}:{self.base}:{self.source}:{self.origin_id}:{self.index}"
 
 
 # required to type hint cls in classmethod
@@ -214,9 +213,7 @@ class OutputSource:
 
         :return:
         """
-        return "{0}:{1}:{2}".format(
-            self.amount, self.base, pypeg2.compose(self.condition, output.Condition)
-        )
+        return f"{self.amount}:{self.base}:{pypeg2.compose(self.condition, output.Condition)}"
 
     def inline_condition(self) -> str:
         """
@@ -296,7 +293,7 @@ class SIGParameter:
 
         :return:
         """
-        return "SIG({0})".format(self.index)
+        return f"SIG({self.index})"
 
 
 # required to type hint cls in classmethod
@@ -355,7 +352,7 @@ class XHXParameter:
 
         :return:
         """
-        return "XHX({0})".format(self.integer)
+        return f"XHX({self.integer})"
 
 
 # required to type hint cls in classmethod
@@ -454,9 +451,8 @@ class Unlock:
 
         :return:
         """
-        return "{0}:{1}".format(
-            self.index, " ".join([str(parameter) for parameter in self.parameters])
-        )
+        params = " ".join([str(parameter) for parameter in self.parameters])
+        return f"{self.index}:{params}"
 
 
 # required to type hint cls in classmethod
@@ -502,12 +498,8 @@ class Transaction(Document):
     re_header = re.compile(
         "TX:([0-9]+):([0-9]+):([0-9]+):([0-9]+):([0-9]+):([01]):([0-9]+)\n"
     )
-    re_compact_blockstamp = re.compile(
-        "({block_uid_regex})\n".format(block_uid_regex=BLOCK_UID_REGEX)
-    )
-    re_blockstamp = re.compile(
-        "Blockstamp: ({block_uid_regex})\n".format(block_uid_regex=BLOCK_UID_REGEX)
-    )
+    re_compact_block_id = re.compile(f"({BLOCK_ID_REGEX})\n")
+    re_block_id = re.compile(f"Blockstamp: ({BLOCK_ID_REGEX})\n")
     re_locktime = re.compile("Locktime: ([0-9]+)\n")
     re_issuers = re.compile("Issuers:\n")
     re_inputs = re.compile("Inputs:\n")
@@ -515,14 +507,14 @@ class Transaction(Document):
     re_outputs = re.compile("Outputs:\n")
     re_compact_comment = re.compile("([^\n]+)\n")
     re_comment = re.compile("Comment: ([^\n]*)\n")
-    re_pubkey = re.compile("({pubkey_regex})\n".format(pubkey_regex=PUBKEY_REGEX))
+    re_pubkey = re.compile(f"({PUBKEY_REGEX})\n")
 
     fields_parsers = {
         **Document.fields_parsers,
         **{
             "Type": re_type,
-            "Blockstamp": re_blockstamp,
-            "CompactBlockstamp": re_compact_blockstamp,
+            "Blockstamp": re_block_id,
+            "CompactBlockstamp": re_compact_block_id,
             "Locktime": re_locktime,
             "TX": re_header,
             "Issuers": re_issuers,
@@ -537,24 +529,22 @@ class Transaction(Document):
 
     def __init__(
         self,
-        version: int,
-        currency: str,
-        blockstamp: Optional[BlockUID],
+        block_id: Optional[BlockID],
         locktime: int,
         issuers: List[str],
         inputs: List[InputSource],
         unlocks: List[Unlock],
         outputs: List[OutputSource],
         comment: str,
-        signatures: List[str],
         time: Optional[int] = None,
+        signing_keys: Optional[Union[SigningKey, List[SigningKey]]] = None,
+        version: int = VERSION,
+        currency: str = G1_CURRENCY_CODENAME,
     ) -> None:
         """
         Init Transaction instance
 
-        :param version: Version number of the document
-        :param currency: Name of the currency
-        :param blockstamp: BlockUID timestamp of the block
+        :param block_id: BlockID instance
         :param locktime: Lock time in seconds
         :param issuers: List of issuers public key
         :param inputs: List of InputSource instances
@@ -562,10 +552,12 @@ class Transaction(Document):
         :param outputs: List of OutputSource instances
         :param comment: Comment field
         :param time: time when the transaction enters the blockchain
-        :param signatures: List of signatures
+        :param signing_keys: SigningKey or list of SigningKey instances to sign the document (default=None)
+        :param version: Document version (default=transaction.VERSION)
+        :param currency: Currency codename (default=constants.CURRENCY_CODENAME_G1)
         """
-        super().__init__(version, currency, signatures)
-        self.blockstamp = blockstamp
+        super().__init__(version, currency)
+        self.block_id = block_id
         self.locktime = locktime
         self.issuers = issuers
         self.inputs = inputs
@@ -573,6 +565,10 @@ class Transaction(Document):
         self.outputs = outputs
         self.comment = comment
         self.time = time
+        self.signatures: List[str] = []
+
+        if signing_keys:
+            self.multi_sign(signing_keys)
 
     def __eq__(self, other: Any) -> bool:
         """
@@ -581,10 +577,9 @@ class Transaction(Document):
         if not isinstance(other, Transaction):
             return NotImplemented
         return (
-            self.version == other.version
-            and self.currency == other.currency
+            super().__eq__(other)
             and self.signatures == other.signatures
-            and self.blockstamp == other.blockstamp
+            and self.block_id == other.block_id
             and self.locktime == other.locktime
             and self.issuers == other.issuers
             and self.inputs == other.inputs
@@ -600,7 +595,7 @@ class Transaction(Document):
                 self.version,
                 self.currency,
                 self.signatures,
-                self.blockstamp,
+                self.block_id,
                 self.locktime,
                 self.issuers,
                 self.inputs,
@@ -613,20 +608,19 @@ class Transaction(Document):
 
     @classmethod
     def from_bma_history(
-        cls: Type[TransactionType], currency: str, tx_data: Dict
+        cls: Type[TransactionType], tx_data: Dict, currency: str = G1_CURRENCY_CODENAME
     ) -> TransactionType:
         """
         Get the transaction instance from json
 
-        :param currency: the currency of the tx
         :param tx_data: json data of the transaction
-
+        :param currency: Currency codename (default=constants.CURRENCY_CODENAME_G1)
         :return:
         """
         tx_data = tx_data.copy()
         tx_data["currency"] = currency
         for data_list in ("issuers", "outputs", "inputs", "unlocks", "signatures"):
-            tx_data["multiline_{0}".format(data_list)] = "\n".join(tx_data[data_list])
+            tx_data[f"multiline_{data_list}"] = "\n".join(tx_data[data_list])
         return cls.from_signed_raw(
             """Version: {version}
 Type: Transaction
@@ -651,13 +645,13 @@ Comment: {comment}
 
     @classmethod
     def from_compact(
-        cls: Type[TransactionType], currency: str, compact: str
+        cls: Type[TransactionType], compact: str, currency: str = G1_CURRENCY_CODENAME
     ) -> TransactionType:
         """
         Return Transaction instance from compact string format
 
-        :param currency: Name of the currency
         :param compact: Compact format string
+        :param currency: Currency codename (default=constants.CURRENCY_CODENAME_G1)
         :return:
         """
         lines = compact.splitlines(True)
@@ -675,7 +669,7 @@ Comment: {comment}
         locktime = int(header_data.group(7))
         n += 1
 
-        blockstamp = BlockUID.from_str(
+        block_id = BlockID.from_str(
             Transaction.parse_field("CompactBlockstamp", lines[n])
         )
         n += 1
@@ -722,19 +716,22 @@ Comment: {comment}
             else:
                 raise MalformedDocumentError("Compact TX Signatures")
 
-        return cls(
-            version,
-            currency,
-            blockstamp,
+        transaction = cls(
+            block_id,
             locktime,
             issuers,
             inputs,
             unlocks,
             outputs,
             comment,
-            signatures,
+            version=version,
+            currency=currency,
         )
 
+        # return transaction with signatures
+        transaction.signatures = signatures
+        return transaction
+
     @classmethod
     def from_signed_raw(
         cls: Type[TransactionType], raw: str, time: int = 0
@@ -759,7 +756,7 @@ Comment: {comment}
         currency = Transaction.parse_field("Currency", lines[n])
         n += 1
 
-        blockstamp = BlockUID.from_str(Transaction.parse_field("Blockstamp", lines[n]))
+        block_id = BlockID.from_str(Transaction.parse_field("Blockstamp", lines[n]))
         n += 1
 
         locktime = Transaction.parse_field("Locktime", lines[n])
@@ -808,55 +805,55 @@ Comment: {comment}
                 signatures.append(sign)
                 n += 1
 
-        return cls(
-            version,
-            currency,
-            blockstamp,
+        transaction = cls(
+            block_id,
             locktime,
             issuers,
             inputs,
             unlocks,
             outputs,
             comment,
-            signatures,
-            time,
+            time=time,
+            version=version,
+            currency=currency,
         )
 
+        # return transaction with signatures
+        transaction.signatures = signatures
+        return transaction
+
     def raw(self) -> str:
         """
         Return raw string format from the instance
 
         :return:
         """
-        doc = """Version: {0}
-Type: Transaction
-Currency: {1}
-""".format(
-            self.version, self.currency
-        )
+        doc = f"Version: {self.version}\n\
+Type: Transaction\n\
+Currency: {self.currency}\n"
 
-        doc += "Blockstamp: {0}\n".format(self.blockstamp)
+        doc += f"Blockstamp: {self.block_id}\n"
 
-        doc += "Locktime: {0}\n".format(self.locktime)
+        doc += f"Locktime: {self.locktime}\n"
 
         doc += "Issuers:\n"
         for p in self.issuers:
-            doc += "{0}\n".format(p)
+            doc += f"{p}\n"
 
         doc += "Inputs:\n"
         for i in self.inputs:
-            doc += "{0}\n".format(i.inline())
+            doc += f"{i.inline()}\n"
 
         doc += "Unlocks:\n"
         for u in self.unlocks:
-            doc += "{0}\n".format(u.inline())
+            doc += f"{u.inline()}\n"
 
         doc += "Outputs:\n"
         for o in self.outputs:
-            doc += "{0}\n".format(o.inline())
+            doc += f"{o.inline()}\n"
 
         doc += "Comment: "
-        doc += "{0}\n".format(self.comment)
+        doc += f"{self.comment}\n"
 
         return doc
 
@@ -874,7 +871,7 @@ Currency: {1}
         PUBLIC_KEY:AMOUNT
         ...
         COMMENT"""
-        doc = "TX:{0}:{1}:{2}:{3}:{4}:{5}:{6}\n".format(
+        doc = "TX:{}:{}:{}:{}:{}:{}:{}\n".format(
             self.version,
             len(self.issuers),
             len(self.inputs),
@@ -883,23 +880,96 @@ Currency: {1}
             "1" if self.comment != "" else "0",
             self.locktime,
         )
-        doc += "{0}\n".format(self.blockstamp)
+        doc += f"{self.block_id}\n"
 
         for pubkey in self.issuers:
-            doc += "{0}\n".format(pubkey)
+            doc += f"{pubkey}\n"
         for i in self.inputs:
-            doc += "{0}\n".format(i.inline())
+            doc += f"{i.inline()}\n"
         for u in self.unlocks:
-            doc += "{0}\n".format(u.inline())
+            doc += f"{u.inline()}\n"
         for o in self.outputs:
-            doc += "{0}\n".format(o.inline())
+            doc += f"{o.inline()}\n"
         if self.comment != "":
-            doc += "{0}\n".format(self.comment)
-        for s in self.signatures:
-            doc += "{0}\n".format(s)
+            doc += f"{self.comment}\n"
+        for signature in self.signatures:
+            doc += f"{signature}\n"
 
         return doc
 
+    def signed_raw(self) -> str:
+        """
+        Return signed raw format string
+
+        :return:
+        """
+        if not self.signatures:
+            raise MalformedDocumentError("No signature, can not create raw format")
+
+        signed_raw = self.raw()
+        for signature in self.signatures:
+            signed_raw += f"{signature}\n"
+
+        return signed_raw
+
+    def sign(self, key: SigningKey) -> None:
+        """
+        Add a signature to the document from key
+
+        :param key: SigningKey instance
+        :return:
+        """
+        self.multi_sign(key)
+
+    def multi_sign(self, keys: Union[SigningKey, List[SigningKey]]) -> None:
+        """
+        Add signature(s) to the document from one key or a list of multiple keys
+
+        :param keys: Libnacl key or list of them
+        """
+        if isinstance(keys, SigningKey):
+            keys = [keys]
+
+        for key in keys:
+            signature = base64.b64encode(key.signature(bytes(self.raw(), "ascii")))
+            logging.debug("Signature:\n%s", signature.decode("ascii"))
+            self.signatures.append(signature.decode("ascii"))
+
+    def check_signature(self, pubkey: str) -> bool:
+        """
+        Check if document is signed by pubkey
+
+        :param pubkey: Base58 pubkey
+        :return:
+        """
+        return self.check_signatures(pubkey)
+
+    def check_signatures(self, pubkeys: Union[str, List[str]]) -> bool:
+        """
+        Check if the signatures matches a public key or a list of public keys
+
+        :param pubkeys: Base58 public key or list of them
+
+        :return:
+        """
+        if not self.signatures:
+            raise Exception("No signatures, can not check signatures")
+
+        if isinstance(pubkeys, str):
+            pubkeys = [pubkeys]
+
+        if len(self.signatures) != len(pubkeys):
+            raise Exception("Number of pubkeys not equal to number of signatures")
+
+        content_to_verify = self.raw()
+
+        validation = True
+        for pubkey, signature in zip(pubkeys, self.signatures):
+            verifying_key = VerifyingKey(pubkey)
+            validation = verifying_key.check_signature(content_to_verify, signature)
+
+        return validation
+
 
 class SimpleTransaction(Transaction):
     """
@@ -909,45 +979,45 @@ class SimpleTransaction(Transaction):
 
     def __init__(
         self,
-        version: int,
-        currency: str,
-        blockstamp: BlockUID,
+        block_id: BlockID,
         locktime: int,
         issuer: str,
         single_input: InputSource,
         unlocks: List[Unlock],
         outputs: List[OutputSource],
         comment: str,
-        signature: str,
-        time: int,
+        time: int = 0,
+        signing_keys: Optional[Union[SigningKey, List[SigningKey]]] = None,
+        version: int = VERSION,
+        currency: str = G1_CURRENCY_CODENAME,
     ) -> None:
         """
         Init instance
 
-        :param version: Version number of the document
-        :param currency: Name of the currency
-        :param blockstamp: BlockUID timestamp
+        :param block_id: BlockID instance
         :param locktime: Lock time in seconds
         :param issuer: Issuer public key
         :param single_input: InputSource instance
         :param unlocks: List of Unlock instances
         :param outputs: List of OutputSource instances
         :param comment: Comment field
-        :param time: time when the transaction enters the blockchain
-        :param signature: Signature
+        :param time: time when the transaction enters the blockchain (default=0)
+        :param signing_keys: SigningKey instance to sign the document (default=None)
+        :param version: Document version (default=transaction.VERSION)
+        :param currency: Currency codename (default=constants.CURRENCY_CODENAME_G1)
         """
         super().__init__(
-            version,
-            currency,
-            blockstamp,
+            block_id,
             locktime,
             [issuer],
             [single_input],
             unlocks,
             outputs,
             comment,
-            [signature],
-            time,
+            time=time,
+            signing_keys=signing_keys,
+            version=version,
+            currency=currency,
         )
 
     @staticmethod
