@@ -1,26 +1,24 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import json
-
 from typing import Optional
 
+from duniterpy.constants import G1_CURRENCY_CODENAME
 from duniterpy.documents import Document
-from duniterpy.key import VerifyingKey, SigningKey
+from duniterpy.key import SigningKey
 from duniterpy.tools import get_ws2p_challenge
 
 
@@ -30,25 +28,20 @@ class HandshakeMessage(Document):
 
     def __init__(
         self,
-        currency: str,
         pubkey: str,
         challenge: Optional[str] = None,
         signature: Optional[str] = None,
+        currency: str = G1_CURRENCY_CODENAME,
     ) -> None:
         """
         Init Connect message document
 
-        :param currency: Name of the currency
         :param pubkey: Public key of the node
         :param challenge: [Optional, default=None] Big random string, typically an uuid
         :param signature: [Optional, default=None] Base64 encoded signature of raw formated document
+        :param currency: Currency codename (default=constants.CURRENCY_CODENAME_G1)
         """
-        if signature is not None:
-            signatures = [signature]
-        else:
-            signatures = []
-
-        super().__init__(self.version, currency, signatures)
+        super().__init__(self.version, currency)
 
         self.pubkey = pubkey
 
@@ -59,9 +52,8 @@ class HandshakeMessage(Document):
             self.challenge = challenge
 
         if signature is not None:
-            # verify signature
-            verifying_key = VerifyingKey(self.pubkey)
-            verifying_key.verify_document(self)
+            self.signature = signature
+            self.check_signature(pubkey)
 
     def raw(self):
         """
@@ -69,12 +61,7 @@ class HandshakeMessage(Document):
 
         :return:
         """
-        return "WS2P:{auth}:{currency}:{pub}:{challenge}".format(
-            auth=self.auth,
-            currency=self.currency,
-            pub=self.pubkey,
-            challenge=self.challenge,
-        )
+        return f"WS2P:{self.auth}:{self.currency}:{self.pubkey}:{self.challenge}"
 
     def get_signed_json(self, signing_key: SigningKey) -> str:
         """
@@ -84,12 +71,12 @@ class HandshakeMessage(Document):
 
         :return:
         """
-        self.sign([signing_key])
+        self.sign(signing_key)
         data = {
             "auth": self.auth,
             "pub": self.pubkey,
             "challenge": self.challenge,
-            "sig": self.signatures[0],
+            "sig": self.signature,
         }
         return json.dumps(data)
 
@@ -106,20 +93,20 @@ class Ack(HandshakeMessage):
 
     def __init__(
         self,
-        currency: str,
         pubkey: str,
         challenge: str,
         signature: Optional[str] = None,
+        currency: str = G1_CURRENCY_CODENAME,
     ) -> None:
         """
         Init Connect message document
 
-        :param currency: Name of the currency
         :param pubkey: Public key of the node
         :param challenge: Big random string, typically an uuid
         :param signature: [Optional, default=None] Base64 encoded signature of raw formated document
+        :param currency: Currency codename (default=constants.CURRENCY_CODENAME_G1)
         """
-        super().__init__(currency, pubkey, challenge, signature)
+        super().__init__(pubkey, challenge, signature, currency)
 
     def get_signed_json(self, signing_key: SigningKey) -> str:
         """
@@ -129,8 +116,8 @@ class Ack(HandshakeMessage):
 
         :return:
         """
-        self.sign([signing_key])
-        data = {"auth": self.auth, "pub": self.pubkey, "sig": self.signatures[0]}
+        self.sign(signing_key)
+        data = {"auth": self.auth, "pub": self.pubkey, "sig": self.signature}
         return json.dumps(data)
 
 
@@ -139,20 +126,20 @@ class Ok(HandshakeMessage):
 
     def __init__(
         self,
-        currency: str,
         pubkey: str,
         challenge: str,
         signature: Optional[str] = None,
+        currency: str = G1_CURRENCY_CODENAME,
     ) -> None:
         """
         Init Connect message document
 
-        :param currency: Name of the currency
         :param pubkey: Public key of the node
         :param challenge: Big random string, typically an uuid
         :param signature: [Optional, default=None] Base64 encoded signature of raw formated document
+        :param currency: Currency codename (default=constants.CURRENCY_CODENAME_G1)
         """
-        super().__init__(currency, pubkey, challenge, signature)
+        super().__init__(pubkey, challenge, signature, currency)
 
     def get_signed_json(self, signing_key: SigningKey) -> str:
         """
@@ -162,8 +149,8 @@ class Ok(HandshakeMessage):
 
         :return:
         """
-        self.sign([signing_key])
-        data = {"auth": self.auth, "sig": self.signatures[0]}
+        self.sign(signing_key)
+        data = {"auth": self.auth, "sig": self.signature}
         return json.dumps(data)
 
 
