@@ -1,25 +1,23 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+from typing import Any, Optional, Type, TypeVar, Union
 
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
+from pypeg2 import Enum, K, Keyword, attr, contiguous, maybe_some, re, whitespace
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
-
-from typing import Optional, TypeVar, Type, Any, Union
-
-from pypeg2 import re, attr, Keyword, Enum, contiguous, maybe_some, whitespace, K
-
-from ..constants import PUBKEY_REGEX, HASH_REGEX
+from ..constants import HASH_REGEX, PUBKEY_REGEX
 
 
 class Pubkey(str):
@@ -103,7 +101,7 @@ class SIG:
         :param attr_of: Attribute of...
         :return:
         """
-        return "SIG({0})".format(self.pubkey)
+        return f"SIG({self.pubkey})"
 
 
 # required to type hint cls in classmethod
@@ -162,7 +160,7 @@ class CSV:
         :param grammar: Grammar
         :param attr_of: Attribute of...
         """
-        return "CSV({0})".format(self.time)
+        return f"CSV({self.time})"
 
 
 # required to type hint cls in classmethod
@@ -221,7 +219,7 @@ class CLTV:
         :param grammar: Grammar
         :param attr_of: Attribute of...
         """
-        return "CLTV({0})".format(self.timestamp)
+        return f"CLTV({self.timestamp})"
 
 
 # required to type hint cls in classmethod
@@ -280,7 +278,7 @@ class XHX:
         :param grammar: Grammar
         :param attr_of: Attribute of...
         """
-        return "XHX({0})".format(self.sha_hash)
+        return f"XHX({self.sha_hash})"
 
 
 # required to type hint cls in classmethod
@@ -316,7 +314,7 @@ class Operator(Keyword):
         :param grammar: Grammar
         :param attr_of: Attribute of...
         """
-        return "{0}".format(self.name)
+        return f"{self.name}"
 
 
 # required to type hint cls in classmethod
@@ -392,23 +390,15 @@ class Condition:
         :param grammar: Grammar
         :param attr_of: Attribute of...
         """
+        left = parser.compose(self.left, grammar=grammar, attr_of=attr_of)
         if type(self.left) is Condition:
-            left = "({0})".format(
-                parser.compose(self.left, grammar=grammar, attr_of=attr_of)
-            )
-        else:
-            left = parser.compose(self.left, grammar=grammar, attr_of=attr_of)
-
+            left = f"({left})"
         if getattr(self, "op", None):
-
+            right = parser.compose(self.right, grammar=grammar, attr_of=attr_of)
             if type(self.right) is Condition:
-                right = "({0})".format(
-                    parser.compose(self.right, grammar=grammar, attr_of=attr_of)
-                )
-            else:
-                right = parser.compose(self.right, grammar=grammar, attr_of=attr_of)
+                right = f"({right})"
             op = parser.compose(self.op, grammar=grammar, attr_of=attr_of)
-            result = "{0} {1} {2}".format(left, op, right)
+            result = f"{left} {op} {right}"
         else:
             result = left
         return result
