@@ -1,29 +1,25 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
-
-import asyncio
 import getpass
 import os
-import sys
 from typing import Optional
 
 from duniterpy.api import bma
 from duniterpy.api.client import Client
-from duniterpy.documents import Revocation, BlockUID, Identity
+from duniterpy.documents import Identity, Revocation
 from duniterpy.key import SigningKey
 
 if "XDG_CONFIG_HOME" in os.environ:
@@ -49,14 +45,10 @@ REVOCATION_DOCUMENT_FILE_PATH = os.path.join(
     home_path, "duniter_account_revocation_document.txt"
 )
 
-# Current protocol version
-PROTOCOL_VERSION = 10
-
-
 ################################################
 
 
-async def get_identity_document(
+def get_identity_document(
     client: Client, current_block: dict, pubkey: str
 ) -> Optional[Identity]:
     """
@@ -69,31 +61,11 @@ async def get_identity_document(
     :rtype: Identity
     """
     # Here we request for the path wot/lookup/pubkey
-    lookup_data = await client(bma.wot.lookup, pubkey)
-    identity = None
+    lookup_response = client(bma.wot.lookup, pubkey)
 
-    # parse results
-    for result in lookup_data["results"]:
-        if result["pubkey"] == pubkey:
-            uids = result["uids"]
-            uid_data = uids[0]
-            # capture data
-            timestamp = BlockUID.from_str(uid_data["meta"]["timestamp"])
-            uid = uid_data["uid"]  # type: str
-            signature = uid_data["self"]  # type: str
-
-            # return self-certification document
-            identity = Identity(
-                version=10,
-                currency=current_block["currency"],
-                pubkey=pubkey,
-                uid=uid,
-                ts=timestamp,
-                signature=signature,
-            )
-            break
-
-    return identity
+    return Identity.from_bma_lookup_response(
+        current_block["currency"], pubkey, lookup_response
+    )
 
 
 def get_signed_raw_revocation_document(
@@ -108,14 +80,13 @@ def get_signed_raw_revocation_document(
 
     :rtype: str
     """
-    revocation = Revocation(PROTOCOL_VERSION, identity.currency, identity, "")
-
     key = SigningKey.from_credentials(salt, password)
-    revocation.sign([key])
+    revocation = Revocation(identity, key, currency=identity.currency)
+
     return revocation.signed_raw()
 
 
-async def main():
+def save_revoke_document():
     """
     Main code
     """
@@ -123,7 +94,7 @@ async def main():
     client = Client(BMAS_ENDPOINT)
 
     # Get the node summary infos to test the connection
-    response = await client(bma.node.summary)
+    response = client(bma.node.summary)
     print(response)
 
     # prompt hidden user entry
@@ -141,18 +112,17 @@ async def main():
     # check public key
     if signer.pubkey != pubkey:
         print("Bad credentials!")
-        sys.exit(0)
+        return
 
     # capture current block to get currency name
-    current_block = await client(bma.blockchain.current)
+    current_block = client(bma.blockchain.current)
 
-    # create our Identity document to sign the Certification document
-    identity = await get_identity_document(client, current_block, pubkey)
+    # create our Identity document to sign the revocation document
+    identity = get_identity_document(client, current_block, pubkey)
     if identity is None:
-        print("Identity not found for pubkey {0}".format(pubkey))
+        print(f"Identity not found for pubkey {pubkey}")
         # Close client aiohttp session
-        await client.close()
-        sys.exit(1)
+        return
 
     # get the revoke document
     revocation_signed_raw_document = get_signed_raw_revocation_document(
@@ -160,17 +130,12 @@ async def main():
     )
 
     # save revoke document in a file
-    fp = open(REVOCATION_DOCUMENT_FILE_PATH, "w")
-    fp.write(revocation_signed_raw_document)
-    fp.close()
+    with open(REVOCATION_DOCUMENT_FILE_PATH, "w", encoding="utf-8") as fp:
+        fp.write(revocation_signed_raw_document)
 
     # document saved
-    print("Revocation document saved in %s" % REVOCATION_DOCUMENT_FILE_PATH)
-
-    # Close client aiohttp session
-    await client.close()
+    print(f"Revocation document saved in {REVOCATION_DOCUMENT_FILE_PATH}")
 
 
-# Latest duniter-python-api is asynchronous and you have to use asyncio, an asyncio loop and a "as" on the data.
-# ( https://docs.python.org/3/library/asyncio.html )
-asyncio.get_event_loop().run_until_complete(main())
+if __name__ == "__main__":
+    save_revoke_document()
