@@ -1,26 +1,24 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
-
-import asyncio
 import getpass
+import urllib
 
 from duniterpy.api import bma
 from duniterpy.api.client import Client
-from duniterpy.documents import BlockUID, Identity
+from duniterpy.documents import BlockID, Identity
 from duniterpy.key import SigningKey
 
 # CONFIG #######################################
@@ -49,26 +47,22 @@ def get_identity_document(
     :rtype: Identity
     """
 
-    # get current block BlockStamp
-    timestamp = BlockUID(current_block["number"], current_block["hash"])
+    # get current BlockID
+    block_id = BlockID(current_block["number"], current_block["hash"])
 
     # create identity document
     identity = Identity(
-        version=10,
-        currency=current_block["currency"],
         pubkey=key.pubkey,
         uid=uid,
-        ts=timestamp,
-        signature=None,
+        block_id=block_id,
+        signing_key=key,
+        currency=current_block["currency"],
     )
 
-    # sign document
-    identity.sign([key])
-
     return identity
 
 
-async def main():
+def send_identity():
     """
     Main code
     """
@@ -76,11 +70,11 @@ async def main():
     client = Client(BMAS_ENDPOINT)
 
     # Get the node summary infos to test the connection
-    response = await client(bma.node.summary)
+    response = client(bma.node.summary)
     print(response)
 
-    # capture current block to get version and currency and blockstamp
-    current_block = await client(bma.blockchain.current)
+    # capture current block to get version and currency and block_id
+    current_block = client(bma.blockchain.current)
 
     # prompt entry
     uid = input("Enter your Unique IDentifier (pseudonym): ")
@@ -98,16 +92,11 @@ async def main():
     identity = get_identity_document(current_block, uid, key)
 
     # send the identity signed raw document to the node
-    response = await client(bma.wot.add, identity.signed_raw())
-    if response.status == 200:
-        print(await response.text())
-    else:
-        print("Error while publishing identity : {0}".format(await response.text()))
-
-    # Close client aiohttp session
-    await client.close()
+    try:
+        client(bma.wot.add, identity.signed_raw())
+    except urllib.error.HTTPError as e:
+        print(f"Error while publishing identity: {e}")
 
 
-# Latest duniter-python-api is asynchronous and you have to use asyncio, an asyncio loop and a "as" on the data.
-# ( https://docs.python.org/3/library/asyncio.html )
-asyncio.get_event_loop().run_until_complete(main())
+if __name__ == "__main__":
+    send_identity()
