@@ -1,32 +1,30 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
-
-import sys
-import asyncio
 import getpass
+import urllib
+from typing import List, Union
 
 from duniterpy.api import bma
 from duniterpy.api.client import Client
-from duniterpy.documents import BlockUID, Transaction
+from duniterpy.documents import BlockID, Transaction
 from duniterpy.documents.transaction import (
     InputSource,
     OutputSource,
-    Unlock,
     SIGParameter,
+    Unlock,
 )
 from duniterpy.key import SigningKey
 
@@ -37,15 +35,15 @@ from duniterpy.key import SigningKey
 # Here we use the secure BASIC_MERKLED_API (BMAS)
 BMAS_ENDPOINT = "BMAS g1-test.duniter.org 443"
 
-# Version of the transaction document
-TRANSACTION_VERSION = 10
-
-
 ################################################
 
 
 def get_transaction_document(
-    current_block: dict, source: dict, from_pubkey: str, to_pubkey: str
+    current_block: dict,
+    source: dict,
+    from_pubkey: str,
+    to_pubkey: str,
+    signing_keys: Union[SigningKey, List[SigningKey]],
 ) -> Transaction:
     """
     Return a Transaction document
@@ -54,6 +52,7 @@ def get_transaction_document(
     :param source: Source to send
     :param from_pubkey: Public key of the issuer
     :param to_pubkey: Public key of the receiver
+    :param signing_key: Signing key of the issuer
 
     :return: Transaction
     """
@@ -86,27 +85,26 @@ def get_transaction_document(
         OutputSource(
             amount=source["amount"],
             base=source["base"],
-            condition="SIG({0})".format(to_pubkey),
+            condition=f"SIG({to_pubkey})",
         )
     ]
 
     transaction = Transaction(
-        version=TRANSACTION_VERSION,
-        currency=current_block["currency"],
-        blockstamp=BlockUID(current_block["number"], current_block["hash"]),
+        block_id=BlockID(current_block["number"], current_block["hash"]),
         locktime=0,
         issuers=issuers,
         inputs=inputs,
         unlocks=unlocks,
         outputs=outputs,
         comment="",
-        signatures=[],
+        signing_keys=signing_keys,
+        currency=current_block["currency"],
     )
 
     return transaction
 
 
-async def main():
+def send_transaction():
     """
     Main code
     """
@@ -114,7 +112,7 @@ async def main():
     client = Client(BMAS_ENDPOINT)
 
     # Get the node summary infos to test the connection
-    response = await client(bma.node.summary)
+    response = client(bma.node.summary)
     print(response)
 
     # prompt hidden user entry
@@ -130,39 +128,30 @@ async def main():
     # prompt entry
     pubkey_to = input("Enter recipient pubkey: ")
 
-    # capture current block to get version and currency and blockstamp
-    current_block = await client(bma.blockchain.current)
+    # capture current block to get version and currency and block_id
+    current_block = client(bma.blockchain.current)
 
     # capture sources of account
-    response = await client(bma.tx.sources, pubkey_from)
+    response = client(bma.tx.sources, pubkey_from)
 
     if len(response["sources"]) == 0:
-        print("no sources found for account %s" % pubkey_to)
-        sys.exit(1)
+        print(f"no sources found for account {pubkey_to}")
+        return
 
     # get the first source
     source = response["sources"][0]
 
     # create the transaction document
     transaction = get_transaction_document(
-        current_block, source, pubkey_from, pubkey_to
+        current_block, source, pubkey_from, pubkey_to, key
     )
 
-    # sign document
-    transaction.sign([key])
-
     # send the Transaction document to the node
-    response = await client(bma.tx.process, transaction.signed_raw())
-
-    if response.status == 200:
-        print(await response.text())
-    else:
-        print("Error while publishing transaction: {0}".format(await response.text()))
-
-    # Close client aiohttp session
-    await client.close()
+    try:
+        client(bma.tx.process, transaction.signed_raw())
+    except urllib.error.HTTPError as e:
+        print(f"Error while publishing transaction: {e}")
 
 
-# Latest duniter-python-api is asynchronous and you have to use asyncio, an asyncio loop and a "as" on the data.
-# ( https://docs.python.org/3/library/asyncio.html )
-asyncio.get_event_loop().run_until_complete(main())
+if __name__ == "__main__":
+    send_transaction()
