@@ -1,40 +1,38 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import json
 import unittest
 
 import jsonschema
 
-from duniterpy.api.client import parse_text
 from duniterpy.api.bma.network import WS2P_HEADS_SCHEMA
+from duniterpy.api.client import parse_text
 from duniterpy.api.ws2p.requests import (
     BLOCK_RESPONSE_SCHEMA,
-    ERROR_RESPONSE_SCHEMA,
     BLOCKS_RESPONSE_SCHEMA,
+    ERROR_RESPONSE_SCHEMA,
     REQUIREMENTS_RESPONSE_SCHEMA,
 )
-from duniterpy.documents import Identity, BlockUID
+from duniterpy.documents import BlockID, Identity
 from duniterpy.documents.ws2p.messages import DocumentMessage
-from tests.api.webserver import WebFunctionalSetupMixin
 
 
-class TestWs2p(WebFunctionalSetupMixin, unittest.TestCase):
-    def test_block(self):
+class TestWs2p(unittest.TestCase):
+    @staticmethod
+    def test_block():
         json_sample = {
             "heads": [
                 {
@@ -190,12 +188,11 @@ class TestWs2p(WebFunctionalSetupMixin, unittest.TestCase):
         document_message = DocumentMessage()
         # prepare document
         identity_document = Identity(
-            10,
-            "beta_brousouf",
             "HgTTJLAQ5sqfknMq7yLPZbehtuLSsKj9CxWN7k8QvYJd",
             "lolcat",
-            BlockUID(32, "DB30D958EE5CB75186972286ED3F4686B8A1C2CD"),
-            "J3G9oM5AKYZNLAB5Wx499w61NuUoS57JVccTShUbGpCMjCqj9yXXqNq7dyZpDWA6BxipsiaMZhujMeBfCznzyci",
+            BlockID(32, "DB30D958EE5CB75186972286ED3F4686B8A1C2CD"),
+            version=10,
+            currency="beta_brousouf",
         )
         # get json string message
         json_document_message = document_message.get_json(
@@ -209,7 +206,6 @@ class TestWs2p(WebFunctionalSetupMixin, unittest.TestCase):
         self.assertIn("name", dict_document_message["body"])
         self.assertIn("identity", dict_document_message["body"])
         self.assertEqual(4, dict_document_message["body"]["name"])
-        expected = """HgTTJLAQ5sqfknMq7yLPZbehtuLSsKj9CxWN7k8QvYJd\
-:J3G9oM5AKYZNLAB5Wx499w61NuUoS57JVccTShUbGpCMjCqj9yXXqNq7dyZpDWA6BxipsiaMZhujMeBfCznzyci:32\
--DB30D958EE5CB75186972286ED3F4686B8A1C2CD:lolcat"""
+        expected = """HgTTJLAQ5sqfknMq7yLPZbehtuLSsKj9CxWN7k8QvYJd:None:\
+32-DB30D958EE5CB75186972286ED3F4686B8A1C2CD:lolcat"""
         self.assertEqual(expected, dict_document_message["body"]["identity"])
