@@ -1,19 +1,17 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
 
@@ -51,7 +49,7 @@ class TestPeer(unittest.TestCase):
         self.assertEqual(peer.currency, "beta_brousouf")
         self.assertEqual(peer.pubkey, "HsLShAtzXTVxeUtQd7yi5Z5Zh4zNvbu8sTEZ53nfKcqY")
         self.assertEqual(
-            str(peer.blockUID), "8-1922C324ABC4AF7EF7656734A31F5197888DDD52"
+            str(peer.block_id), "8-1922C324ABC4AF7EF7656734A31F5197888DDD52"
         )
         self.assertEqual(len(peer.endpoints), 4)
         self.assertIsInstance(peer.endpoints[0], BMAEndpoint)
@@ -59,22 +57,22 @@ class TestPeer(unittest.TestCase):
         self.assertIsInstance(peer.endpoints[2], WS2PEndpoint)
         self.assertIsInstance(peer.endpoints[3], UnknownEndpoint)
 
-        self.assertEqual(peer.endpoints[0].server, "some.dns.name")
+        self.assertEqual(peer.endpoints[0].host, "some.dns.name")
         self.assertEqual(peer.endpoints[0].ipv4, "88.77.66.55")
         self.assertEqual(peer.endpoints[0].ipv6, "2001:42d0:52:a00::648")
         self.assertEqual(peer.endpoints[0].port, 9001)
 
-        self.assertEqual(peer.endpoints[1].server, "some.dns.name")
+        self.assertEqual(peer.endpoints[1].host, "some.dns.name")
         self.assertEqual(peer.endpoints[1].ipv4, "88.77.66.55")
         self.assertEqual(peer.endpoints[1].ipv6, "2001:42d0:52:a00::648")
         self.assertEqual(peer.endpoints[1].port, 9002)
 
-        self.assertEqual(peer.endpoints[2].server, "g1-test.duniter.org")
+        self.assertEqual(peer.endpoints[2].host, "g1-test.duniter.org")
         self.assertEqual(peer.endpoints[2].ws2pid, "d2edcb92")
         self.assertEqual(peer.endpoints[2].port, 20902)
 
         self.assertEqual(
-            peer.signatures[0],
+            peer.signature,
             "dkaXIiCYUJtCg8Feh/BKvPYf4uFH9CJ/zY6J4MlA9BsjmcMe4YAblvNt/gJy31b1aGq3ue3h14mLMCu84rraDg==",
         )
 
@@ -88,7 +86,7 @@ class TestPeer(unittest.TestCase):
             from_rendered_peer.pubkey, "HsLShAtzXTVxeUtQd7yi5Z5Zh4zNvbu8sTEZ53nfKcqY"
         )
         self.assertEqual(
-            str(from_rendered_peer.blockUID),
+            str(from_rendered_peer.block_id),
             "8-1922C324ABC4AF7EF7656734A31F5197888DDD52",
         )
         self.assertEqual(len(peer.endpoints), 4)
@@ -97,22 +95,22 @@ class TestPeer(unittest.TestCase):
         self.assertIsInstance(peer.endpoints[2], WS2PEndpoint)
         self.assertIsInstance(peer.endpoints[3], UnknownEndpoint)
 
-        self.assertEqual(from_rendered_peer.endpoints[0].server, "some.dns.name")
+        self.assertEqual(from_rendered_peer.endpoints[0].host, "some.dns.name")
         self.assertEqual(from_rendered_peer.endpoints[0].ipv4, "88.77.66.55")
         self.assertEqual(from_rendered_peer.endpoints[0].ipv6, "2001:42d0:52:a00::648")
         self.assertEqual(from_rendered_peer.endpoints[0].port, 9001)
 
-        self.assertEqual(from_rendered_peer.endpoints[1].server, "some.dns.name")
+        self.assertEqual(from_rendered_peer.endpoints[1].host, "some.dns.name")
         self.assertEqual(from_rendered_peer.endpoints[1].ipv4, "88.77.66.55")
         self.assertEqual(from_rendered_peer.endpoints[1].ipv6, "2001:42d0:52:a00::648")
         self.assertEqual(from_rendered_peer.endpoints[1].port, 9002)
 
-        self.assertEqual(peer.endpoints[2].server, "g1-test.duniter.org")
+        self.assertEqual(peer.endpoints[2].host, "g1-test.duniter.org")
         self.assertEqual(peer.endpoints[2].ws2pid, "d2edcb92")
         self.assertEqual(peer.endpoints[2].port, 20902)
 
         self.assertEqual(
-            from_rendered_peer.signatures[0],
+            from_rendered_peer.signature,
             "dkaXIiCYUJtCg8Feh/BKvPYf4uFH9CJ/zY6J4MlA9BsjmcMe4YAblvNt/gJy31b1aGq3ue3h14mLMCu84rraDg==",
         )
         self.assertEqual(rawpeer, from_rendered_peer.signed_raw())
