@@ -1,26 +1,25 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
-
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import base64
 import os
-
-from duniterpy.key import VerifyingKey, SigningKey, PublicKey
-from duniterpy.key.scrypt_params import ScryptParams
 import unittest
 
+from duniterpy.key import PublicKey, SigningKey, VerifyingKey
+from duniterpy.key.scrypt_params import ScryptParams
+
 TEST_FILE_PATH = "/tmp/test_file.txt"
 
 
@@ -99,8 +98,8 @@ class TestSigningKey(unittest.TestCase):
         salt = password = "test"
 
         # create a dummy credentials file
-        with open(TEST_FILE_PATH, "w") as fh:
-            fh.write("{}\n{}\n".format(salt, password))
+        with open(TEST_FILE_PATH, "w", encoding="utf-8") as fh:
+            fh.write(f"{salt}\n{password}\n")
 
         # same key from credentials
         sign_key_test = SigningKey.from_credentials(salt, password)
@@ -129,7 +128,7 @@ class TestSigningKey(unittest.TestCase):
         """
 
         # create dummy .ssb/secret file
-        with open(TEST_FILE_PATH, "w") as fh:
+        with open(TEST_FILE_PATH, "w", encoding="utf-8") as fh:
             fh.write(dummy_content)
         # test load file
         sign_key_load = SigningKey.from_credentials_file(TEST_FILE_PATH)
@@ -144,3 +143,16 @@ class TestSigningKey(unittest.TestCase):
             sign_key_load.vk.hex(),
             "d27f4cb2bfadbaf45b61714b896d4639ab90db035aee746611cdd342bdaa8996",
         )
+
+    def test_dubp_mnemonic(self):
+        mnemonic = (
+            "tongue cute mail fossil great frozen same social weasel impact brush kind"
+        )
+
+        keypair = SigningKey.from_dubp_mnemonic(mnemonic)
+
+        self.assertEqual(
+            base64.b64encode(keypair.seed).decode("utf-8"),
+            "qGdvpbP9lJe7ZG4ZUSyu33KFeAEs/KkshAp9gEI4ReY=",
+        )
+        self.assertEqual(keypair.pubkey, "732SSfuwjB7jkt9th1zerGhphs6nknaCBCTozxUcPWPU")
