@@ -1,28 +1,27 @@
-"""
-Copyright  2014-2021 Vincent Texier <vit@free.fr>
+# Copyright  2014-2022 Vincent Texier <vit@free.fr>
+#
+# DuniterPy is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# DuniterPy is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-DuniterPy is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-DuniterPy is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
-
-from duniterpy.key import VerifyingKey, SigningKey
-from duniterpy.key.scrypt_params import ScryptParams
-from duniterpy.documents.peer import Peer
-from duniterpy.documents.ws2p.heads import HeadV0, HeadV1, HeadV2
-from duniterpy.documents import Block
-from duniterpy.documents.transaction import Transaction
 import unittest
 
+from duniterpy.documents import Block
+from duniterpy.documents.peer import Peer
+from duniterpy.documents.transaction import Transaction
+from duniterpy.documents.ws2p.heads import HeadV0, HeadV1, HeadV2
+from duniterpy.key import SigningKey, VerifyingKey
+from duniterpy.key.scrypt_params import ScryptParams
+
 
 class TestVerifyingKey(unittest.TestCase):
     def test_from_sign_to_verify(self):
@@ -55,8 +54,7 @@ BASIC_MERKLED_API testnet.duniter.inso.ovh 80
 """
         peer = Peer.from_signed_raw(signed_raw)
         pubkey = "8Fi1VSTbjkXguwThF4v2ZxC5whK7pwG2vcGTkPUPjPGU"
-        verifying_key = VerifyingKey(pubkey)
-        self.assertTrue(verifying_key.verify_document(peer))
+        self.assertTrue(peer.check_signature(pubkey))
 
     def test_ws2p_headv0(self):
         headv0, _ = HeadV0.from_inline(
@@ -66,8 +64,9 @@ BASIC_MERKLED_API testnet.duniter.inso.ovh 80
             "+BaXzmArj7kwlItbdGUs4fc9QUG5Lp4TwPS7nhOM5t1Kt6CA==",
         )
 
-        verifying_key = VerifyingKey(headv0.pubkey)
-        self.assertTrue(verifying_key.verify_ws2p_head(headv0))
+        self.assertTrue(
+            headv0.check_signature("3dnbnYY9i2bHMQUGyFp5GVvJ2wBkVpus31cDJA5cfRpj")
+        )
 
     def test_ws2p_headv1(self):
         headv1, _ = HeadV1.from_inline(
@@ -78,8 +77,9 @@ BASIC_MERKLED_API testnet.duniter.inso.ovh 80
             "+hdZRqf0iUWRNuhxlequ68kkwMaE6ymBw==",
         )
 
-        verifying_key = VerifyingKey(headv1.pubkey)
-        self.assertTrue(verifying_key.verify_ws2p_head(headv1))
+        self.assertTrue(
+            headv1.check_signature("HbTqJ1Ts3RhJ8Rx4XkNyh1oSKmoZL1kY5U7t9mKTSjAB")
+        )
 
     def test_ws2p_headv2(self):
         headv2, _ = HeadV2.from_inline(
@@ -90,8 +90,9 @@ BASIC_MERKLED_API testnet.duniter.inso.ovh 80
             "+yNoHonqBSqirAQ==",
         )
 
-        verifying_key = VerifyingKey(headv2.pubkey)
-        self.assertTrue(verifying_key.verify_ws2p_head(headv2))
+        self.assertTrue(
+            headv2.check_signature("D3krfq6J9AmfpKnS3gQVYoy7NzGCc61vokteTS8LJ4YH")
+        )
 
     def test_block_document(self):
         block_document = """Version: 10
@@ -122,8 +123,7 @@ Nonce: 10300000099432
 """
         block_signature = "Uxa3L+/m/dWLex2xSh7Jv1beAn4f99BmoYAs7iX3Lr+t1l5jzJpd9m4iI1cHppIizCgbg6ztaiZedQ+Mp6KuDg=="
         block = Block.from_signed_raw(block_document + block_signature + "\n")
-        verifying_key = VerifyingKey(block.issuer)
-        self.assertTrue(verifying_key.verify_document(block))
+        self.assertTrue(block.check_signature(block.issuer))
 
     def test_transaction_document(self):
         transaction_document = """TX:10:1:6:6:2:1:0
@@ -146,6 +146,5 @@ Nonce: 10300000099432
 Solde huile Millepertuis
 rgjOmzFH5h+hkDbJLk1b88X7Z83HMgTa5rBckeMSdF/yZtItN3zMn09MphcXjffdrKcK+MebwoisLJqV+jXrDg==
 """
-        tx = Transaction.from_compact("g1", transaction_document)
-        verifying_key = VerifyingKey(tx.issuers[0])
-        self.assertTrue(verifying_key.verify_document(tx))
+        tx = Transaction.from_compact(transaction_document, "g1")
+        self.assertTrue(tx.check_signatures(tx.issuers))
